@@ -407,16 +407,16 @@ def main():
 	except FileExistsError:
 		pass
 	if not isfile('%s/pavlovadm.conf'%cfgdir):
-		with open('usr/local/share/pavlovadm/pavlovadm.conf', 'r') as lfh, open('%s/pavlovadm.conf'%cfgdir, 'w+') as gfh:
+		with open('/usr/local/share/pavlovadm/pavlovadm.conf', 'r') as lfh, open('%s/pavlovadm.conf'%cfgdir, 'w+') as gfh:
 			gfh.write(lfh.read())
 	if not isfile('%s/Games.ini'%cfgdir):
-		with open('usr/local/share/pavlovadm/Game.ini', 'r') as lfh, open('%s/Game.ini'%cfgdir, 'w+') as gfh:
+		with open('/usr/local/share/pavlovadm/Game.ini', 'r') as lfh, open('%s/Game.ini'%cfgdir, 'w+') as gfh:
 			gfh.write(lfh.read())
 	if not isfile('%s/public.ini'%cfgdir):
-		with open('usr/local/share/pavlovadm/public.ini', 'r') as lfh, open('%s/public.ini'%cfgdir, 'w+') as gfh:
+		with open('/usr/local/share/pavlovadm/public.ini', 'r') as lfh, open('%s/public.ini'%cfgdir, 'w+') as gfh:
 			gfh.write(lfh.read())
 	if not isfile('%s/BalancingTable.csv'%cfgdir):
-		with open('usr/local/share/pavlovadm/BalancingTable.csv', 'r') as lfh, open('%s/BalancingTable.csv'%cfgdir, 'w+') as gfh:
+		with open('/usr/local/share/pavlovadm/BalancingTable.csv', 'r') as lfh, open('%s/BalancingTable.csv'%cfgdir, 'w+') as gfh:
 			gfh.write(lfh.read())
 	cfgs = config('%s/%s.conf'%(__me, __me))
 
